@@ -43,7 +43,7 @@ class Bitpin:
         # set timeout from requests_params
         if requests_params is not None:
             self.__timeout = requests_params.get('timeout') or 10
-            self.__verify = requests_params.get('verify') or True
+            self.__verify = requests_params.get('verify') or None
         else:
             self.__timeout = 10
             self.__verify = True
@@ -284,6 +284,16 @@ class Bitpin:
                 f_args=f_args
             )
 
+    def set_token(self, token: str):
+        """
+        Set new fresh token
+
+        :param token: str
+        :return: None
+        """
+
+        self.__access_token = token
+
     def login(self) -> t.Dict:
         """
         Get token.
@@ -295,7 +305,7 @@ class Bitpin:
         f_name = cf().f_code.co_name
         f_args = self.__get_func_args(locals())
 
-        url = '/v1/usr/api/login'
+        url = '/v1/usr/api/login/'
 
         response = self._request(
             f_name,
@@ -341,7 +351,7 @@ class Bitpin:
         f_name = cf().f_code.co_name
         f_args = self.__get_func_args(locals())
 
-        url = '/v1/usr/info'
+        url = '/v1/usr/info/'
 
         response = self._request(
             f_name,
@@ -366,7 +376,7 @@ class Bitpin:
         f_name = cf().f_code.co_name
         f_args = self.__get_func_args(locals())
 
-        url = '/v1/mkt/currencies'
+        url = '/v1/mkt/currencies/'
 
         params = {
             'page': page,
@@ -396,7 +406,7 @@ class Bitpin:
         f_name = cf().f_code.co_name
         f_args = self.__get_func_args(locals())
 
-        url = '/v1/mkt/markets'
+        url = '/v1/mkt/markets/'
 
         params = {
             'page': page,
@@ -423,7 +433,7 @@ class Bitpin:
         f_name = cf().f_code.co_name
         f_args = self.__get_func_args(locals())
 
-        url = '/v1/wlt/wallets'
+        url = '/v1/wlt/wallets/'
 
         response = self._request(
             f_name,
@@ -454,7 +464,7 @@ class Bitpin:
         if type(market_id) is MarketsIDs:
             market_id = market_id.value
 
-        url = f'/v2/mth/actives/{market_id}'
+        url = f'/v2/mth/actives/{market_id}/'
 
         side = side.lower() if side else None
 
@@ -466,7 +476,7 @@ class Bitpin:
             )
         else:
             params = {
-                'side': side,
+                'type': side,
             }
 
         response = self._request(
@@ -496,7 +506,7 @@ class Bitpin:
         if type(market_id) is CurrenciesIDs:
             market_id = market_id.value
 
-        url = f'/v1/mth/matches/{market_id}'
+        url = f'/v1/mth/matches/{market_id}/'
 
         response = self._request(
             f_name,
